'use strict';

var _lodash = _interopRequireDefault(require("lodash"));

var _devices = _interopRequireDefault(require("./devices"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const supportedFormats = ['pdf', 'png', 'jpeg', 'bmp', 'ppm'];

const viewportsNames = _lodash.default.map(_devices.default, 'name');

const viewportStringPattern = /^(\d{1,4})(?:x)?(\d{1,4})?$/;

const isValidViewport = input => {
  if (_lodash.default.isString(input)) {
    if (viewportStringPattern.test(input)) {
      return true;
    }

    return viewportsNames.includes(input.replace(/\s+/g, '-').toLowerCase());
  }

  if (_lodash.default.isArray(input)) {
    return _lodash.default.every(input, isValidViewport);
  }

  if (_lodash.default.isNumber(input)) {
    return true;
  }

  return false;
};

module.exports = {
  isValidViewport: isValidViewport,
  validateViewport: v => {
    if (_lodash.default.isString(v) && v.indexOf(',') > -1) {
      v = v.split(',');
    }

    if (!isValidViewport(v)) {
      throw new Error(`Viewport ${v} is not supported, check the documentation to see which values are supported`);
    }

    return v;
  },
  validateFormat: v => {
    v = v.toLowerCase();

    if (supportedFormats.includes(v)) {
      return v;
    }

    throw new Error(`Format ${v} is not supported, must be one of [${supportedFormats.join(',')}]`);
  }
};