"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isValidViewport = isValidViewport;
exports.validateViewport = validateViewport;
exports.validateFormat = validateFormat;

var _ = _interopRequireWildcard(require("lodash"));

var _devices = _interopRequireDefault(require("../devices"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const supportedFormats = ['pdf', 'png', 'jpeg', 'bmp', 'ppm'];

const viewportsNames = _.map(_devices.default, 'name');

const viewportStringPattern = /^(\d{1,4})(?:x)?(\d{1,4})?$/;

function isValidViewport(input) {
  if (_.isString(input)) {
    if (viewportStringPattern.test(input)) {
      return true;
    }

    return viewportsNames.includes(input.replace(/\s+/g, '-').toLowerCase());
  }

  if (_.isArray(input)) {
    return _.every(input, isValidViewport);
  }

  if (_.isNumber(input)) {
    return true;
  }

  return false;
}

function validateViewport(v) {
  if (_.isString(v) && v.indexOf(',') > -1) {
    v = v.split(',');
  }

  if (!isValidViewport(v)) {
    throw new Error(`Viewport ${v} is not supported, check the documentation to see which values are supported`);
  }

  return v;
}

function validateFormat(v) {
  v = v.toLowerCase();

  if (supportedFormats.includes(v)) {
    return v;
  }

  throw new Error(`Format ${v} is not supported, must be one of [${supportedFormats.join(',')}]`);
}